@@ -1,19 +1,21 @@
 //! The `TerminalDuplex` struct.
 
-use crate::{
-    config::{detect_read_write_config, ReadConfig, WriteConfig},
-    DuplexTerminal, ReadTerminal, Terminal, TerminalColorSupport, WriteTerminal,
-};
+use crate::config::{detect_read_write_config, ReadConfig, WriteConfig};
+use crate::{DuplexTerminal, ReadTerminal, Terminal, TerminalColorSupport, WriteTerminal};
 use duplex::{Duplex, HalfDuplex};
-use std::{
-    fmt,
-    io::{self, IoSlice, IoSliceMut, Read, Write},
-};
-#[cfg(not(windows))]
-use unsafe_io::os::posish::{AsRawReadWriteFd, RawFd};
+use std::fmt;
+use std::io::{self, IoSlice, IoSliceMut, Read, Write};
 #[cfg(windows)]
-use unsafe_io::os::windows::{AsRawReadWriteHandleOrSocket, RawHandleOrSocket};
+use unsafe_io::os::windows::{
+    AsRawReadWriteHandleOrSocket, AsReadWriteHandleOrSocket, BorrowedHandleOrSocket,
+    RawHandleOrSocket,
+};
 use unsafe_io::AsReadWriteGrip;
+#[cfg(not(windows))]
+use {
+    io_lifetimes::BorrowedFd,
+    unsafe_io::os::rsix::{AsRawReadWriteFd, AsReadWriteFd, RawFd},
+};
 
 /// A wrapper around a `Read` + `Write` which adds minimal terminal support.
 #[derive(Debug)]
@@ -73,6 +75,19 @@ impl<Inner: Duplex + AsRawReadWriteFd> AsRawReadWriteFd for TerminalDuplexer<Inn
     }
 }
 
+#[cfg(not(windows))]
+impl<Inner: Duplex + AsReadWriteFd> AsReadWriteFd for TerminalDuplexer<Inner> {
+    #[inline]
+    fn as_read_fd(&self) -> BorrowedFd<'_> {
+        self.inner.as_read_fd()
+    }
+
+    #[inline]
+    fn as_write_fd(&self) -> BorrowedFd<'_> {
+        self.inner.as_write_fd()
+    }
+}
+
 #[cfg(windows)]
 impl<Inner: Duplex + AsRawReadWriteHandleOrSocket> AsRawReadWriteHandleOrSocket
     for TerminalDuplexer<Inner>
@@ -88,6 +103,21 @@ impl<Inner: Duplex + AsRawReadWriteHandleOrSocket> AsRawReadWriteHandleOrSocket
     }
 }
 
+#[cfg(windows)]
+impl<Inner: Duplex + AsReadWriteHandleOrSocket> AsReadWriteHandleOrSocket
+    for TerminalDuplexer<Inner>
+{
+    #[inline]
+    fn as_read_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.inner.as_read_handle_or_socket()
+    }
+
+    #[inline]
+    fn as_write_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.inner.as_write_handle_or_socket()
+    }
+}
+
 impl<Inner: Duplex> Terminal for TerminalDuplexer<Inner> {}
 
 impl<Inner: Duplex + Read + Write> ReadTerminal for TerminalDuplexer<Inner> {
