@@ -1,15 +1,18 @@
 //! The `TerminalReader` struct.
 
-use crate::{
-    config::{detect_read_config, ReadConfig},
-    ReadTerminal, Terminal,
-};
+use crate::config::{detect_read_config, ReadConfig};
+use crate::{ReadTerminal, Terminal};
 use std::io::{self, IoSliceMut, Read};
-#[cfg(unix)]
-use unsafe_io::os::posish::{AsRawFd, RawFd};
 #[cfg(windows)]
-use unsafe_io::os::windows::{AsRawHandleOrSocket, RawHandleOrSocket};
+use unsafe_io::os::windows::{
+    AsHandleOrSocket, AsRawHandleOrSocket, BorrowedHandleOrSocket, RawHandleOrSocket,
+};
 use unsafe_io::AsGrip;
+#[cfg(not(windows))]
+use {
+    io_lifetimes::{AsFd, BorrowedFd},
+    unsafe_io::os::rsix::{AsRawFd, RawFd},
+};
 
 /// A wrapper around a `Read` which adds minimal terminal support.
 #[derive(Debug)]
@@ -54,6 +57,14 @@ impl<Inner: Read + AsRawFd> AsRawFd for TerminalReader<Inner> {
     }
 }
 
+#[cfg(not(windows))]
+impl<Inner: Read + AsFd> AsFd for TerminalReader<Inner> {
+    #[inline]
+    fn as_fd(&self) -> BorrowedFd<'_> {
+        self.inner.as_fd()
+    }
+}
+
 #[cfg(windows)]
 impl<Inner: Read + AsRawHandleOrSocket> AsRawHandleOrSocket for TerminalReader<Inner> {
     #[inline]
@@ -62,6 +73,14 @@ impl<Inner: Read + AsRawHandleOrSocket> AsRawHandleOrSocket for TerminalReader<I
     }
 }
 
+#[cfg(windows)]
+impl<Inner: Read + AsHandleOrSocket> AsHandleOrSocket for TerminalReader<Inner> {
+    #[inline]
+    fn as_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.inner.as_handle_or_socket()
+    }
+}
+
 impl<Inner: Read> Terminal for TerminalReader<Inner> {}
 
 impl<Inner: Read> ReadTerminal for TerminalReader<Inner> {
