@@ -1,18 +1,19 @@
 //! The `TerminalWriter` struct.
 
-use crate::{
-    config::{detect_write_config, WriteConfig},
-    Terminal, TerminalColorSupport, WriteTerminal,
-};
-use std::{
-    fmt,
-    io::{self, IoSlice, Write},
-};
-#[cfg(not(windows))]
-use unsafe_io::os::posish::{AsRawFd, RawFd};
+use crate::config::{detect_write_config, WriteConfig};
+use crate::{Terminal, TerminalColorSupport, WriteTerminal};
+use std::fmt;
+use std::io::{self, IoSlice, Write};
 #[cfg(windows)]
-use unsafe_io::os::windows::{AsRawHandleOrSocket, RawHandleOrSocket};
+use unsafe_io::os::windows::{
+    AsHandleOrSocket, AsRawHandleOrSocket, BorrowedHandleOrSocket, RawHandleOrSocket,
+};
 use unsafe_io::AsGrip;
+#[cfg(not(windows))]
+use {
+    io_lifetimes::{AsFd, BorrowedFd},
+    unsafe_io::os::rsix::{AsRawFd, RawFd},
+};
 
 /// A wrapper around a `Write` which adds minimal terminal support.
 #[derive(Debug)]
@@ -79,6 +80,14 @@ impl<Inner: Write + AsRawFd> AsRawFd for TerminalWriter<Inner> {
     }
 }
 
+#[cfg(not(windows))]
+impl<Inner: Write + AsFd> AsFd for TerminalWriter<Inner> {
+    #[inline]
+    fn as_fd(&self) -> BorrowedFd {
+        self.inner.as_fd()
+    }
+}
+
 #[cfg(windows)]
 impl<Inner: Write + AsRawHandleOrSocket> AsRawHandleOrSocket for TerminalWriter<Inner> {
     #[inline]
@@ -87,6 +96,14 @@ impl<Inner: Write + AsRawHandleOrSocket> AsRawHandleOrSocket for TerminalWriter<
     }
 }
 
+#[cfg(windows)]
+impl<Inner: Write + AsHandleOrSocket> AsHandleOrSocket for TerminalWriter<Inner> {
+    #[inline]
+    fn as_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.inner.as_handle_or_socket()
+    }
+}
+
 impl<Inner: Write> Terminal for TerminalWriter<Inner> {}
 
 impl<Inner: Write> WriteTerminal for TerminalWriter<Inner> {
